Package: nextGenShinyApps
Type: Package
Title: Craft Exceptional 'R Shiny' Applications and Dashboards with
        Novel Responsive Tools
Version: 2.1
Authors@R: c(
    person("Obinna", "Obianom", email = "idonshayo@gmail.com", role = c("aut", "cre")))
Maintainer: Obinna Obianom <idonshayo@gmail.com>
Description: Novel responsive tools for developing R based 'Shiny' dashboards and applications. The scripts and style sheets are based on 'jQuery' <https://jquery.com/> and 'Bootstrap' <https://getbootstrap.com/>.
License: MIT + file LICENSE
URL: https://nextgenshinyapps.obi.obianom.com
BugReports: https://github.com/oobianom/nextGenShinyApps
Depends: R (>= 3.4)
Imports: utils, shiny, htmltools, quickcode
Suggests: rmarkdown, knitr, r2dictionary, r2resize, r2social
Encoding: UTF-8
VignetteBuilder: knitr
Language: en-US
LazyData: false
RoxygenNote: 7.2.3
NeedsCompilation: no
Author: Obinna Obianom [aut, cre]
Packaged: 2024-07-29 19:19:48 UTC; in198
Repository: CRAN
Date/Publication: 2024-07-29 22:00:10 UTC
Built: R 4.6.0; ; 2026-04-28 19:47:41 UTC; unix
